@@ -153,7 +153,7 @@ class OpenLineageClient:
     ) -> Event | None:
         """Filters jobs according to config-defined events"""
         for _filter in self._filters:
-            if isinstance(event, RunEvent) and _filter.filter_event(event) is None:
+            if isinstance(event, (RunEvent, event_v2.RunEvent)) and _filter.filter_event(event) is None:
                 return None
         return event
 
@@ -163,6 +163,11 @@ class OpenLineageClient:
         if type(event) not in get_args(Event):
             msg = "`emit` only accepts RunEvent, DatasetEvent, JobEvent classes"
             raise ValueError(msg)
+
+        if log.isEnabledFor(logging.DEBUG):
+            val = Serde.to_json(event).encode("utf-8")
+            log.debug("OpenLineageClient will *try* to emit event %s", val)
+
         if not self.transport:
             log.error("Tried to emit OpenLineage event, but transport is not configured.")
             return
@@ -176,9 +181,6 @@ class OpenLineageClient:
         event = self.add_environment_facets(event)
         event = self.update_event_tags_facets(event)
 
-        if log.isEnabledFor(logging.DEBUG):
-            val = Serde.to_json(event).encode("utf-8")
-            log.debug("OpenLineageClient will emit event %s", val)
         self.transport.emit(event)
         log.debug("OpenLineage event successfully emitted.")
 
@@ -395,7 +397,10 @@ class OpenLineageClient:
         """
         Adds environment variables as facets to the event object.
         """
-        if isinstance(event, RunEvent) and (env_vars := self._collect_environment_variables()):
+        if isinstance(event, (RunEvent, event_v2.RunEvent)) and (
+            env_vars := self._collect_environment_variables()
+        ):
+            event.run.facets = event.run.facets or {}
             event.run.facets["environmentVariables"] = EnvironmentVariablesRunFacet(
                 environmentVariables=[
                     EnvironmentVariable(name=name, value=value) for name, value in env_vars.items()
@@ -420,15 +425,21 @@ class OpenLineageClient:
         """
         Creates or updates job and run tag facets based on user-supplied environment variables
         """
+        run_event_types = (RunEvent, event_v2.RunEvent)
+        run_and_job_event_types = (RunEvent, event_v2.RunEvent, JobEvent, event_v2.JobEvent)
         tags_job = self.config.tags.job
-        if (isinstance(event, (JobEvent, RunEvent))) and tags_job:
+        if isinstance(event, run_and_job_event_types) and tags_job:
+            # Ensure facets exists
+            event.job.facets = {} if not event.job.facets else event.job.facets
             tags_facet = event.job.facets.get("tags", TagsJobFacet())
-            event.job.facets["tags"] = self._update_tag_facet(tags_facet, tags_job)  # type: ignore [arg-type]
+            event.job.facets["tags"] = self._update_tag_facet(tags_facet, tags_job)  # type: ignore [arg-type, assignment]
 
         tags_run = self.config.tags.run
-        if (isinstance(event, RunEvent)) and tags_run:
+        if isinstance(event, run_event_types) and tags_run:
+            # Ensure facets exists
+            event.run.facets = {} if not event.run.facets else event.run.facets
             tags_facet = event.run.facets.get("tags", TagsRunFacet())
-            event.run.facets["tags"] = self._update_tag_facet(tags_facet, tags_run)  # type: ignore [arg-type]
+            event.run.facets["tags"] = self._update_tag_facet(tags_facet, tags_run)  # type: ignore [arg-type, assignment]
 
         return event
 
