@@ -9,6 +9,7 @@ from typing import TYPE_CHECKING
 from unittest.mock import MagicMock, patch
 
 import pytest
+from openlineage.client import event_v2
 from openlineage.client.client import OpenLineageClient, OpenLineageClientOptions, OpenLineageConfig
 from openlineage.client.facets import FacetsConfig
 from openlineage.client.generated.environment_variables_run import (
@@ -103,7 +104,7 @@ def test_client_sends_proper_json_with_minimal_run_event() -> None:
     session.post.assert_called_with(
         url="http://example.com/api/v1/lineage",
         data=body,
-        headers={},
+        headers={"Content-Type": "application/json"},
         timeout=5.0,
         verify=True,
     )
@@ -131,7 +132,7 @@ def test_client_sends_proper_json_with_minimal_dataset_event() -> None:
     session.post.assert_called_with(
         url="http://example.com/api/v1/lineage",
         data=body,
-        headers={},
+        headers={"Content-Type": "application/json"},
         timeout=5.0,
         verify=True,
     )
@@ -160,7 +161,7 @@ def test_client_sends_proper_json_with_minimal_job_event() -> None:
     session.post.assert_called_with(
         url="http://example.com/api/v1/lineage",
         data=body,
-        headers={},
+        headers={"Content-Type": "application/json"},
         timeout=5.0,
         verify=True,
     )
@@ -216,11 +217,10 @@ def test_client_filters_exact_job_name_events(
         factory.create.return_value = transport
         client = OpenLineageClient(factory=factory)
 
-        run = Run(runId=str(generate_new_uuid()))
         event = RunEvent(
             eventType=RunState.START,
             eventTime="2021-11-03T10:53:52.427343",
-            run=run,
+            run=Run(runId=str(generate_new_uuid())),
             job=Job(name=name, namespace=""),
             producer="",
             schemaURL="",
@@ -229,6 +229,20 @@ def test_client_filters_exact_job_name_events(
         client.emit(event)
         assert transport.emit.called == should_emit
 
+        transport.emit.reset_mock()
+        assert transport.emit.called is False
+
+        event2 = event_v2.RunEvent(
+            eventType=event_v2.RunState.START,
+            eventTime="2021-11-03T10:53:52.427343",
+            run=event_v2.Run(runId=str(generate_new_uuid())),
+            job=event_v2.Job(name=name, namespace=""),
+            producer="",
+        )
+
+        client.emit(event2)
+        assert transport.emit.called == should_emit
+
 
 def test_setting_ol_client_log_level() -> None:
     default_log_level = logging.WARNING
@@ -478,6 +492,22 @@ def test_add_environment_facets():
         [EnvironmentVariable(name="ENV_VAR_1", value="value1")]
     )
 
+    event2 = event_v2.RunEvent(
+        eventType=event_v2.RunState.START,
+        eventTime="2021-11-03T10:53:52.427343",
+        run=run,
+        job=event_v2.Job(name="name", namespace=""),
+        producer="",
+    )
+    event2.run.facets = {}
+
+    modified_event2 = client.add_environment_facets(event2)
+
+    assert "environmentVariables" in modified_event2.run.facets
+    assert modified_event2.run.facets["environmentVariables"] == EnvironmentVariablesRunFacet(
+        [EnvironmentVariable(name="ENV_VAR_1", value="value1")]
+    )
+
 
 @patch("openlineage.client.client.OpenLineageClient._find_yaml_config_path")
 @patch("openlineage.client.client.OpenLineageClient._get_config_file_content")
@@ -638,6 +668,21 @@ def test_add_environment_facets_with_custom_env_var(mock_resolve_transport) -> N
         "environmentVariables"
     ] == EnvironmentVariablesRunFacet([EnvironmentVariable(name="CUSTOM_ENV_VAR", value="custom_value")])
 
+    mock_transport.emit.reset_mock()
+    assert mock_transport.emit.call_args is None
+
+    event2 = event_v2.RunEvent(
+        eventType=event_v2.RunState.START,
+        eventTime="2021-11-03T10:53:52.427343",
+        run=run,
+        job=event_v2.Job(name="name", namespace=""),
+        producer="",
+    )
+    client.emit(event2)
+    assert mock_transport.emit.call_args[0][0].run.facets[
+        "environmentVariables"
+    ] == EnvironmentVariablesRunFacet([EnvironmentVariable(name="CUSTOM_ENV_VAR", value="custom_value")])
+
 
 @patch.dict(
     os.environ,
@@ -865,6 +910,28 @@ class TestOpenLineageConfigLoader:
                     }
                 },
             ),
+            (
+                {
+                    "OPENLINEAGE__TRANSPORT__TYPE": "http",
+                    "OPENLINEAGE__TRANSPORT__URL": "http://localhost:5050",
+                    "OPENLINEAGE__TRANSPORT__RETRY__TOTAL": "5",
+                    "OPENLINEAGE__TRANSPORT__RETRY__BACKOFF_FACTOR": "0.2",
+                    "OPENLINEAGE__TRANSPORT__RETRY__ALLOWED_METHODS": '["GET", "POST"]',
+                    "OPENLINEAGE__TRANSPORT__RETRY__STATUS_FORCELIST": "[500, 502, 503, 504]",
+                },
+                {
+                    "transport": {
+                        "type": "http",
+                        "url": "http://localhost:5050",
+                        "retry": {
+                            "total": 5,
+                            "backoff_factor": 0.2,
+                            "allowed_methods": ["GET", "POST"],
+                            "status_forcelist": [500, 502, 503, 504],
+                        },
+                    }
+                },
+            ),
         ],
     )
     @patch.dict(os.environ, {})
@@ -874,20 +941,63 @@ class TestOpenLineageConfigLoader:
             assert config == expected_config
 
 
-def test_update_job_tag_facet_creates_new_facet(transport):
+@pytest.fixture(
+    scope="module", params=[("V1", RunEvent, Job, Run), ("V2", event_v2.RunEvent, event_v2.Job, event_v2.Run)]
+)
+def run_event_multi(request):
+    """
+    Parameterized run events that allow us to test both versions for run events
+    """
+    event_version = request.param[0]
+    event_type = request.param[1]
+    job_type = request.param[2]
+    run_type = request.param[3]
+
+    job = job_type(name="name", namespace="namespace")
+    run = run_type(runId="69f4acab-b87d-4fc0-b27b-8ea950370ff3")
+    event_args = {
+        "eventTime": "2021-11-03T10:53:52.427343",
+        "eventType": RunState.START,
+        "producer": "producer",
+        "schemaURL": "http:foo.com/schema",
+        "job": job,
+        "run": run,
+    }
+    if event_version == "V2":
+        del event_args["eventType"]
+        del event_args["schemaURL"]
+
+    return event_type(**event_args)
+
+
+@pytest.fixture(scope="module", params=[("V1", JobEvent, Job), ("V2", event_v2.JobEvent, event_v2.Job)])
+def job_event_multi(request):
+    """
+    Parameterized job events that allow us to test both versions for job events
+    """
+    event_version = request.param[0]
+    event_type = request.param[1]
+    job_type = request.param[2]
+
+    job_args = {"name": "name", "namespace": "namespace"}
+    job = job_type(**job_args)
+    event_args = {
+        "eventTime": "2021-11-03T10:53:52.427343",
+        "producer": "producer",
+        "schemaURL": "http:foo.com/schema",
+        "job": job,
+    }
+    if event_version == "V2":
+        del event_args["schemaURL"]
+    return event_type(**event_args)
+
+
+def test_client_creates_new_job_tag_facet(transport, run_event_multi):
     tag_environment_variables = {
         "OPENLINEAGE__TAGS__JOB__ENVIRONMENT": "PRODUCTION",
         "OPENLINEAGE__TAGS__JOB__pipeline": "SALES",
     }
 
-    run_event = RunEvent(
-        RunState.START,
-        "2021-11-03T10:53:52.427343",
-        Run("69f4acab-b87d-4fc0-b27b-8ea950370ff3"),
-        Job("openlineage", "job"),
-        "producer",
-    )
-
     tags = [
         TagsJobFacetFields("environment", "PRODUCTION", "USER"),
         TagsJobFacetFields("pipeline", "SALES", "USER"),
@@ -895,39 +1005,25 @@ def test_update_job_tag_facet_creates_new_facet(transport):
 
     with patch.dict(os.environ, tag_environment_variables):
         client = OpenLineageClient(transport=transport)
-        client.emit(run_event)
+        client.emit(run_event_multi)
         assert transport.event.job.facets.get("tags")
         event_tags = sorted(transport.event.job.facets["tags"].tags, key=lambda x: x.key)
         expected_tags = sorted(tags, key=lambda x: x.key)
         assert event_tags == expected_tags
 
 
-def test_update_job_tag_facet_updates_existing_facet(transport):
+def test_client_updates_existing_job_tags_facet(transport, run_event_multi):
     tag_environment_variables = {
         "OPENLINEAGE__TAGS__JOB__ENVIRONMENT": "PRODUCTION",
         "OPENLINEAGE__TAGS__JOB__pipeline": "SALES",
     }
 
-    run_event = RunEvent(
-        RunState.START,
-        "2021-11-03T10:53:52.427343",
-        Run("69f4acab-b87d-4fc0-b27b-8ea950370ff3"),
-        Job(
-            namespace="openlineage",
-            name="job",
-            facets={
-                "tags": TagsRunFacet(
-                    tags=[
-                        TagsJobFacetFields("environment", "STAGING", "USER"),
-                        TagsJobFacetFields("foo", "bar", "USER"),
-                    ]
-                )
-            },
-        ),
-        "producer",
-    )
+    existing_tags = [
+        TagsJobFacetFields("environment", "STAGING", "USER"),
+        TagsJobFacetFields("foo", "bar", "USER"),
+    ]
+    run_event_multi.job.facets["tags"] = TagsJobFacet(tags=existing_tags)
 
-    # One existing tag (not updated), one existing tag (updated), one new tag from the user
     tags = [
         TagsJobFacetFields("foo", "bar", "USER"),
         TagsJobFacetFields("environment", "PRODUCTION", "USER"),
@@ -936,27 +1032,19 @@ def test_update_job_tag_facet_updates_existing_facet(transport):
 
     with patch.dict(os.environ, tag_environment_variables):
         client = OpenLineageClient(transport=transport)
-        client.emit(run_event)
+        client.emit(run_event_multi)
         assert transport.event.job.facets.get("tags")
         event_tags = sorted(transport.event.job.facets["tags"].tags, key=lambda x: x.key)
         expected_tags = sorted(tags, key=lambda x: x.key)
         assert event_tags == expected_tags
 
 
-def test_update_run_tag_facet_creates_new_facet(transport):
+def test_client_creates_new_run_tags_facet(transport, run_event_multi):
     tag_environment_variables = {
         "OPENLINEAGE__TAGS__RUN__ENVIRONMENT": "PRODUCTION",
         "OPENLINEAGE__TAGS__RUN__pipeline": "SALES",
     }
 
-    run_event = RunEvent(
-        RunState.START,
-        "2021-11-03T10:53:52.427343",
-        Run("69f4acab-b87d-4fc0-b27b-8ea950370ff3"),
-        Job("openlineage", "job"),
-        "producer",
-    )
-
     tags = [
         TagsRunFacetFields("environment", "PRODUCTION", "USER"),
         TagsRunFacetFields("pipeline", "SALES", "USER"),
@@ -964,36 +1052,24 @@ def test_update_run_tag_facet_creates_new_facet(transport):
 
     with patch.dict(os.environ, tag_environment_variables):
         client = OpenLineageClient(transport=transport)
-        client.emit(run_event)
+        client.emit(run_event_multi)
         assert transport.event.run.facets.get("tags")
         event_tags = sorted(transport.event.run.facets["tags"].tags, key=lambda x: x.key)
         expected_tags = sorted(tags, key=lambda x: x.key)
         assert event_tags == expected_tags
 
 
-def test_update_run_tag_facet_updates_existing_facet(transport):
+def test_client_updates_existing_run_tags_facet(transport, run_event_multi):
     tag_environment_variables = {
         "OPENLINEAGE__TAGS__RUN__ENVIRONMENT": "PRODUCTION",
         "OPENLINEAGE__TAGS__RUN__pipeline": "SALES",
     }
 
-    run_event = RunEvent(
-        RunState.START,
-        "2021-11-03T10:53:52.427343",
-        Run(
-            runId="69f4acab-b87d-4fc0-b27b-8ea950370ff3",
-            facets={
-                "tags": TagsJobFacet(
-                    tags=[
-                        TagsRunFacetFields("ENVIRONMENT", "STAGING", "USER"),
-                        TagsRunFacetFields("foo", "bar", "USER"),
-                    ]
-                )
-            },
-        ),
-        Job("openlineage", "job"),
-        "producer",
-    )
+    existing_tags = [
+        TagsRunFacetFields("ENVIRONMENT", "STAGING", "USER"),
+        TagsRunFacetFields("foo", "bar", "USER"),
+    ]
+    run_event_multi.run.facets["tags"] = TagsRunFacet(tags=existing_tags)
 
     # One existing tag (not updated), one existing tag (updated), one new tag from the user
     tags = [
@@ -1004,36 +1080,25 @@ def test_update_run_tag_facet_updates_existing_facet(transport):
 
     with patch.dict(os.environ, tag_environment_variables):
         client = OpenLineageClient(transport=transport)
-        client.emit(run_event)
+        client.emit(run_event_multi)
         assert transport.event.run.facets.get("tags")
         event_tags = sorted(transport.event.run.facets["tags"].tags, key=lambda x: x.key)
         expected_tags = sorted(tags, key=lambda x: x.key)
         assert event_tags == expected_tags
 
 
-def test_update_tag_facet_keeps_key_case(transport):
+def test_client_keeps_key_case_for_existing_tags(transport, run_event_multi):
     tag_environment_variables = {
         "OPENLINEAGE__TAGS__RUN__ENVIRONMENT": "PRODUCTION",
         "OPENLINEAGE__TAGS__RUN__pipeline": "SALES",
     }
 
-    run_event = RunEvent(
-        RunState.START,
-        "2021-11-03T10:53:52.427343",
-        Run(
-            runId="69f4acab-b87d-4fc0-b27b-8ea950370ff3",
-            facets={
-                "tags": TagsJobFacet(
-                    tags=[
-                        TagsRunFacetFields("environment", "STAGING", "USER"),
-                        TagsRunFacetFields("PIPELINE", "FINANCE", "USER"),
-                    ]
-                )
-            },
-        ),
-        Job("openlineage", "job"),
-        "producer",
-    )
+    tags = [
+        TagsRunFacetFields("environment", "STAGING", "USER"),
+        TagsRunFacetFields("PIPELINE", "FINANCE", "USER"),
+    ]
+
+    run_event_multi.run.facets["tags"] = TagsRunFacet(tags=tags)
 
     tags = [
         TagsRunFacetFields("environment", "PRODUCTION", "USER"),
@@ -1042,8 +1107,57 @@ def test_update_tag_facet_keeps_key_case(transport):
 
     with patch.dict(os.environ, tag_environment_variables):
         client = OpenLineageClient(transport=transport)
-        client.emit(run_event)
+        client.emit(run_event_multi)
         assert transport.event.run.facets.get("tags")
         event_tags = sorted(transport.event.run.facets["tags"].tags, key=lambda x: x.key)
         expected_tags = sorted(tags, key=lambda x: x.key)
         assert event_tags == expected_tags
+
+
+def test_client_creates_tag_facets_for_job_events(transport, job_event_multi):
+    """
+    Same code is used for run and job events to update facets. This just verifies
+    it works for job events.
+    """
+    tag_environment_variables = {
+        "OPENLINEAGE__TAGS__JOB__environment": "production",
+        "OPENLINEAGE__TAGS__JOB__pipeline": "sales",
+    }
+
+    tags = [
+        TagsJobFacetFields("environment", "production", "USER"),
+        TagsJobFacetFields("pipeline", "sales", "USER"),
+    ]
+
+    with patch.dict(os.environ, tag_environment_variables):
+        client = OpenLineageClient(transport=transport)
+        client.emit(job_event_multi)
+        assert transport.event.job.facets.get("tags")
+        event_tags = sorted(transport.event.job.facets["tags"].tags, key=lambda x: x.key)
+        expected_tags = sorted(tags, key=lambda x: x.key)
+        assert event_tags == expected_tags
+
+
+def test_client_does_not_update_run_tags_for_job_events(transport, job_event_multi):
+    """
+    Verify we do not try to update run tags in a job event. It will throw and exception
+    if we do.
+    """
+    tag_environment_variables = {
+        "OPENLINEAGE__TAGS__JOB__environment": "production",
+        "OPENLINEAGE__TAGS__JOB__pipeline": "sales",
+        "OPENLINEAGE__TAGS__RUN__pipeline": "sales",
+    }
+
+    tags = [
+        TagsJobFacetFields("environment", "production", "USER"),
+        TagsJobFacetFields("pipeline", "sales", "USER"),
+    ]
+
+    with patch.dict(os.environ, tag_environment_variables):
+        client = OpenLineageClient(transport=transport)
+        client.emit(job_event_multi)
+        assert transport.event.job.facets.get("tags")
+        event_tags = sorted(transport.event.job.facets["tags"].tags, key=lambda x: x.key)
+        expected_tags = sorted(tags, key=lambda x: x.key)
+        assert event_tags == expected_tags
