@@ -6,8 +6,9 @@ from typing import TYPE_CHECKING
 from unittest.mock import ANY, call
 
 import pytest
-from openlineage.client import OpenLineageClient
+from openlineage.client import OpenLineageClient, event_v2
 from openlineage.client.facet import ParentRunFacet
+from openlineage.client.facet_v2 import parent_run
 from openlineage.client.run import (
     Dataset,
     DatasetEvent,
@@ -36,6 +37,17 @@ def run_event() -> RunEvent:
     )
 
 
+@pytest.fixture()
+def run_event_v2() -> RunEvent:
+    return event_v2.RunEvent(
+        eventType=event_v2.RunState.START,
+        eventTime="2024-04-10T15:08:01.333999",
+        run=event_v2.Run(runId="ea445b5c-22eb-457a-8007-01c7c52b6e54"),
+        job=event_v2.Job(namespace="test-namespace", name="test-job"),
+        producer="prod",
+    )
+
+
 @pytest.fixture()
 def run_event_with_parent() -> RunEvent:
     parent_run_facet = ParentRunFacet.create(
@@ -54,6 +66,44 @@ def run_event_with_parent() -> RunEvent:
     )
 
 
+@pytest.fixture()
+def run_event_with_parent_v2() -> RunEvent:
+    parent_run_facet = parent_run.ParentRunFacet(
+        job=parent_run.Job(namespace="parent-namespace", name="parent-job"),
+        run=parent_run.Run(runId="d9cb8e0b-a410-435e-a619-da5e87ba8508"),
+    )
+
+    return event_v2.RunEvent(
+        eventType=event_v2.RunState.START,
+        eventTime="2024-04-10T15:08:01.333999",
+        run=event_v2.Run(runId="ea445b5c-22eb-457a-8007-01c7c52b6e54", facets={"parent": parent_run_facet}),
+        job=event_v2.Job(namespace="test-namespace", name="test-job"),
+        producer="prod",
+    )
+
+
+@pytest.fixture()
+def run_event_with_root_parent_v2() -> RunEvent:
+    root_run = parent_run.Root(
+        job=parent_run.RootJob(namespace="root-namespace", name="root-job"),
+        run=parent_run.RootRun(runId="ad0995e1-49f1-432d-92b6-2e2739034c13"),
+    )
+
+    parent_run_facet = parent_run.ParentRunFacet(
+        job=parent_run.Job(namespace="parent-namespace", name="parent-job"),
+        run=parent_run.Run(runId="d9cb8e0b-a410-435e-a619-da5e87ba8508"),
+        root=root_run,
+    )
+
+    return event_v2.RunEvent(
+        eventType=event_v2.RunState.START,
+        eventTime="2024-04-10T15:08:01.333999",
+        run=event_v2.Run(runId="ea445b5c-22eb-457a-8007-01c7c52b6e54", facets={"parent": parent_run_facet}),
+        job=event_v2.Job(namespace="test-namespace", name="test-job"),
+        producer="prod",
+    )
+
+
 @pytest.fixture()
 def dataset_event() -> DatasetEvent:
     return DatasetEvent(
@@ -64,6 +114,15 @@ def dataset_event() -> DatasetEvent:
     )
 
 
+@pytest.fixture()
+def dataset_event_v2() -> DatasetEvent:
+    return event_v2.DatasetEvent(
+        eventTime="2024-04-10T15:08:01.333999",
+        dataset=event_v2.Dataset(namespace="test-namespace", name="test-dataset"),
+        producer="prod",
+    )
+
+
 @pytest.fixture()
 def job_event() -> JobEvent:
     return JobEvent(
@@ -74,6 +133,15 @@ def job_event() -> JobEvent:
     )
 
 
+@pytest.fixture()
+def job_event_v2() -> JobEvent:
+    return event_v2.JobEvent(
+        eventTime="2024-04-10T15:08:01.333999",
+        job=event_v2.Job(namespace="test-namespace", name="test-job"),
+        producer="prod",
+    )
+
+
 def test_kafka_loads_full_config() -> None:
     config = KafkaConfig.from_dict(
         {
@@ -132,29 +200,64 @@ def test_kafka_load_config_fails_on_no_config() -> None:
         )
 
 
-def test_client_with_kafka_transport_emits_run_event(run_event: RunEvent, mocker: MockerFixture) -> None:
+def test_client_with_kafka_transport_emits_run_event(
+    run_event: RunEvent,
+    run_event_v2: event_v2.RunEvent,
+    mocker: MockerFixture,
+) -> None:
     mocker.patch("confluent_kafka.Producer")
     config = KafkaConfig(
         config={"bootstrap.servers": "localhost:9092"},
         topic="random-topic",
         flush=True,
     )
-    transport = KafkaTransport(config)
 
-    client = OpenLineageClient(transport=transport)
+    for event in [run_event, run_event_v2]:
+        transport = KafkaTransport(config)
 
-    client.emit(run_event)
-    transport.producer.produce.assert_called_once_with(
-        topic="random-topic",
-        key="run:test-namespace/test-job",
-        value=Serde.to_json(run_event).encode("utf-8"),
-        on_delivery=ANY,
-    )
-    transport.producer.flush.assert_called_once()
+        client = OpenLineageClient(transport=transport)
+
+        client.emit(event)
+        transport.producer.produce.assert_called_once_with(
+            topic="random-topic",
+            key="run:test-namespace/test-job",
+            value=Serde.to_json(event).encode("utf-8"),
+            on_delivery=ANY,
+        )
+        transport.producer.flush.assert_called_once()
+        transport.producer.reset_mock()
 
 
 def test_client_with_kafka_transport_emits_run_event_with_parent(
     run_event_with_parent: RunEvent,
+    run_event_with_parent_v2: event_v2.RunEvent,
+    mocker: MockerFixture,
+) -> None:
+    mocker.patch("confluent_kafka.Producer")
+    config = KafkaConfig(
+        config={"bootstrap.servers": "localhost:9092"},
+        topic="random-topic",
+        flush=True,
+    )
+
+    for event in [run_event_with_parent, run_event_with_parent_v2]:
+        transport = KafkaTransport(config)
+
+        client = OpenLineageClient(transport=transport)
+
+        client.emit(event)
+        transport.producer.produce.assert_called_once_with(
+            topic="random-topic",
+            key="run:parent-namespace/parent-job",
+            value=Serde.to_json(event).encode("utf-8"),
+            on_delivery=ANY,
+        )
+        transport.producer.flush.assert_called_once()
+        transport.producer.reset_mock()
+
+
+def test_client_with_kafka_transport_emits_run_event_with_root_parent(
+    run_event_with_root_parent_v2: event_v2.RunEvent,
     mocker: MockerFixture,
 ) -> None:
     mocker.patch("confluent_kafka.Producer")
@@ -167,11 +270,11 @@ def test_client_with_kafka_transport_emits_run_event_with_parent(
 
     client = OpenLineageClient(transport=transport)
 
-    client.emit(run_event_with_parent)
+    client.emit(run_event_with_root_parent_v2)
     transport.producer.produce.assert_called_once_with(
         topic="random-topic",
-        key="run:parent-namespace/parent-job",
-        value=Serde.to_json(run_event_with_parent).encode("utf-8"),
+        key="run:root-namespace/root-job",
+        value=Serde.to_json(run_event_with_root_parent_v2).encode("utf-8"),
         on_delivery=ANY,
     )
     transport.producer.flush.assert_called_once()
@@ -179,6 +282,7 @@ def test_client_with_kafka_transport_emits_run_event_with_parent(
 
 def test_client_with_kafka_transport_emits_run_event_with_explicit_message_key(
     run_event: RunEvent,
+    run_event_v2: event_v2.RunEvent,
     mocker: MockerFixture,
 ) -> None:
     mocker.patch("confluent_kafka.Producer")
@@ -188,43 +292,54 @@ def test_client_with_kafka_transport_emits_run_event_with_explicit_message_key(
         messageKey="explicit-key",
         flush=True,
     )
-    transport = KafkaTransport(config)
 
-    client = OpenLineageClient(transport=transport)
+    for event in [run_event, run_event_v2]:
+        transport = KafkaTransport(config)
 
-    client.emit(run_event)
-    transport.producer.produce.assert_called_once_with(
-        topic="random-topic",
-        key="explicit-key",
-        value=Serde.to_json(run_event).encode("utf-8"),
-        on_delivery=ANY,
-    )
-    transport.producer.flush.assert_called_once()
+        client = OpenLineageClient(transport=transport)
+
+        client.emit(event)
+        transport.producer.produce.assert_called_once_with(
+            topic="random-topic",
+            key="explicit-key",
+            value=Serde.to_json(event).encode("utf-8"),
+            on_delivery=ANY,
+        )
+        transport.producer.flush.assert_called_once()
+        transport.producer.reset_mock()
 
 
-def test_client_with_kafka_transport_emits_job_event(job_event: DatasetEvent, mocker: MockerFixture) -> None:
+def test_client_with_kafka_transport_emits_job_event(
+    job_event: JobEvent,
+    job_event_v2: event_v2.JobEvent,
+    mocker: MockerFixture,
+) -> None:
     mocker.patch("confluent_kafka.Producer")
     config = KafkaConfig(
         config={"bootstrap.servers": "localhost:9092"},
         topic="random-topic",
         flush=True,
     )
-    transport = KafkaTransport(config)
 
-    client = OpenLineageClient(transport=transport)
+    for event in [job_event, job_event_v2]:
+        transport = KafkaTransport(config)
 
-    client.emit(job_event)
-    transport.producer.produce.assert_called_once_with(
-        topic="random-topic",
-        key="job:test-namespace/test-job",
-        value=Serde.to_json(job_event).encode("utf-8"),
-        on_delivery=ANY,
-    )
-    transport.producer.flush.assert_called_once()
+        client = OpenLineageClient(transport=transport)
+
+        client.emit(event)
+        transport.producer.produce.assert_called_once_with(
+            topic="random-topic",
+            key="job:test-namespace/test-job",
+            value=Serde.to_json(event).encode("utf-8"),
+            on_delivery=ANY,
+        )
+        transport.producer.flush.assert_called_once()
+        transport.producer.reset_mock()
 
 
 def test_client_with_kafka_transport_emits_job_event_with_explicit_message_key(
-    job_event: DatasetEvent,
+    job_event: JobEvent,
+    job_event_v2: event_v2.JobEvent,
     mocker: MockerFixture,
 ) -> None:
     mocker.patch("confluent_kafka.Producer")
@@ -234,22 +349,26 @@ def test_client_with_kafka_transport_emits_job_event_with_explicit_message_key(
         messageKey="explicit-key",
         flush=True,
     )
-    transport = KafkaTransport(config)
+    for event in [job_event, job_event_v2]:
+        transport = KafkaTransport(config)
 
-    client = OpenLineageClient(transport=transport)
+        client = OpenLineageClient(transport=transport)
 
-    client.emit(job_event)
-    transport.producer.produce.assert_called_once_with(
-        topic="random-topic",
-        key="explicit-key",
-        value=Serde.to_json(job_event).encode("utf-8"),
-        on_delivery=ANY,
-    )
-    transport.producer.flush.assert_called_once()
+        client.emit(event)
+        transport.producer.produce.assert_called_once_with(
+            topic="random-topic",
+            key="explicit-key",
+            value=Serde.to_json(event).encode("utf-8"),
+            on_delivery=ANY,
+        )
+        transport.producer.flush.assert_called_once()
+        transport.producer.reset_mock()
 
 
 def test_client_with_kafka_transport_emits_dataset_event(
-    dataset_event: DatasetEvent, mocker: MockerFixture
+    dataset_event: DatasetEvent,
+    dataset_event_v2: event_v2.DatasetEvent,
+    mocker: MockerFixture,
 ) -> None:
     mocker.patch("confluent_kafka.Producer")
     config = KafkaConfig(
@@ -257,22 +376,27 @@ def test_client_with_kafka_transport_emits_dataset_event(
         topic="random-topic",
         flush=True,
     )
-    transport = KafkaTransport(config)
 
-    client = OpenLineageClient(transport=transport)
+    for event in [dataset_event, dataset_event_v2]:
+        transport = KafkaTransport(config)
 
-    client.emit(dataset_event)
-    transport.producer.produce.assert_called_once_with(
-        topic="random-topic",
-        key="dataset:test-namespace/test-dataset",
-        value=Serde.to_json(dataset_event).encode("utf-8"),
-        on_delivery=ANY,
-    )
-    transport.producer.flush.assert_called_once()
+        client = OpenLineageClient(transport=transport)
+
+        client.emit(event)
+        transport.producer.produce.assert_called_once_with(
+            topic="random-topic",
+            key="dataset:test-namespace/test-dataset",
+            value=Serde.to_json(event).encode("utf-8"),
+            on_delivery=ANY,
+        )
+        transport.producer.flush.assert_called_once()
+        transport.producer.reset_mock()
 
 
 def test_client_with_kafka_transport_emits_dataset_event_explicit_message_key(
-    dataset_event: DatasetEvent, mocker: MockerFixture
+    dataset_event: DatasetEvent,
+    dataset_event_v2: event_v2.DatasetEvent,
+    mocker: MockerFixture,
 ) -> None:
     mocker.patch("confluent_kafka.Producer")
     config = KafkaConfig(
@@ -281,22 +405,26 @@ def test_client_with_kafka_transport_emits_dataset_event_explicit_message_key(
         messageKey="explicit-key",
         flush=True,
     )
-    transport = KafkaTransport(config)
 
-    client = OpenLineageClient(transport=transport)
+    for event in [dataset_event, dataset_event_v2]:
+        transport = KafkaTransport(config)
 
-    client.emit(dataset_event)
-    transport.producer.produce.assert_called_once_with(
-        topic="random-topic",
-        key="explicit-key",
-        value=Serde.to_json(dataset_event).encode("utf-8"),
-        on_delivery=ANY,
-    )
-    transport.producer.flush.assert_called_once()
+        client = OpenLineageClient(transport=transport)
+
+        client.emit(event)
+        transport.producer.produce.assert_called_once_with(
+            topic="random-topic",
+            key="explicit-key",
+            value=Serde.to_json(event).encode("utf-8"),
+            on_delivery=ANY,
+        )
+        transport.producer.flush.assert_called_once()
+        transport.producer.reset_mock()
 
 
 def test_airflow_sqlalchemy_constructs_producer_each_call(
     run_event: RunEvent,
+    run_event_v2: event_v2.RunEvent,
     mocker: MockerFixture,
 ) -> None:
     mocker.patch(
@@ -304,21 +432,28 @@ def test_airflow_sqlalchemy_constructs_producer_each_call(
         return_value=True,
     )
     mock = mocker.patch("confluent_kafka.Producer")
-    config = KafkaConfig(
-        config={"bootstrap.servers": "localhost:9092"},
-        topic="random-topic",
-        flush=True,
-    )
-    transport = KafkaTransport(config)
 
-    client = OpenLineageClient(transport=transport)
+    for event in [run_event, run_event_v2]:
+        config = KafkaConfig(
+            config={"bootstrap.servers": "localhost:9092"},
+            topic="random-topic",
+            flush=True,
+        )
+        transport = KafkaTransport(config)
 
-    client.emit(run_event)
-    client.emit(run_event)
-    mock.assert_has_calls([call(config.config), call(config.config)], any_order=True)
+        client = OpenLineageClient(transport=transport)
+
+        client.emit(event)
+        client.emit(event)
+        mock.assert_has_calls([call(config.config), call(config.config)], any_order=True)
+        mock.reset_mock()
 
 
-def test_airflow_direct_constructs_producer_once(run_event: RunEvent, mocker: MockerFixture) -> None:
+def test_airflow_direct_constructs_producer_once(
+    run_event: RunEvent,
+    run_event_v2: event_v2.RunEvent,
+    mocker: MockerFixture,
+) -> None:
     mocker.patch(
         "openlineage.client.transport.kafka._check_if_airflow_sqlalchemy_context",
         return_value=False,
@@ -329,10 +464,14 @@ def test_airflow_direct_constructs_producer_once(run_event: RunEvent, mocker: Mo
         topic="random-topic",
         flush=True,
     )
-    transport = KafkaTransport(config)
 
-    client = OpenLineageClient(transport=transport)
+    for event in [run_event, run_event_v2]:
+        transport = KafkaTransport(config)
 
-    client.emit(run_event)
-    client.emit(run_event)
-    mock.assert_called_once_with(config.config)
+        client = OpenLineageClient(transport=transport)
+
+        client.emit(event)
+        client.emit(event)
+
+        mock.assert_called_once_with(config.config)
+        mock.reset_mock()
